LocationJsonService class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
loadCircles(
{String? assetPath, String? jsonRaw}) → Future< List< CircleModel> > - Loads circles from an asset path or raw JSON string.
-
loadDistricts(
{String? assetPath, String? jsonRaw}) → Future< List< DistrictModel> > - Loads districts from an asset path or raw JSON string.
-
loadSubdivisions(
{String? assetPath, String? jsonRaw}) → Future< List< SubdivisionModel> > - Loads subdivisions from an asset path or raw JSON string.